@@ -5,11 +5,13 @@ from .note import LimitRegister, ApplySilence, TransposeDiatonic, TransposeChrom
 from .score import RepeatScore
 from .features import ExtractMainTonality, MostCommonTonalities
 from .chord import RepeatChord, Modulate, ModulateKeepOriginMode
+from .score_merger import ConcatScores, ConcatWithPattern, TakeSlice, TakeFirst, TakeLast, TakeIdx
 
 __all__ = ['create_counterpoint', 'create_counterpoint_on_score',
            'CircularPermutationMelody', 'SelectRangeMelody', 'ReverseMelody', 'InvertMelody',
            'RepeatScore', 'ReverseMelodyWithoutRhythm',
             'LimitRegister', 'ApplySilence', 'TransposeDiatonic', 'TransposeChromatic', 'ApplyContinuation',
             'ExtractMainTonality', 'MostCommonTonalities',
-            'RepeatChord', 'Modulate', 'ModulateKeepOriginMode'
+            'RepeatChord', 'Modulate', 'ModulateKeepOriginMode',
+           'ConcatScores', 'ConcatWithPattern', 'TakeSlice', 'TakeFirst', 'TakeLast', 'TakeIdx'
            ]
